@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2009
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,8 +24,8 @@
 #include "general.h"
 #include "project.h"
 
+
 void uc_application_progress_dialog_set_modal (const gboolean modal);
-void uc_application_clean_data (void);
 void uc_application_buffer_show (const gchar * title, const gchar * message);
 void uc_application_w3c_validate (void);
 gchar *uc_application_input_file_dialog (const gchar * title,
@@ -40,7 +40,8 @@ gboolean uc_application_cookie_warning_dialog_show (const gchar * server,
 						    gchar ** expires,
 						    const UCCookiesAction
 						    action);
-gboolean uc_application_auth_dialog_show (const gchar * title);
+gboolean uc_application_auth_dialog_show (const gchar * title,
+                                          const gchar *host);
 void uc_application_set_status_bar (const gfloat progress, const gchar * msg);
 void uc_application_open_project_dialog_show (void);
 gboolean uc_application_project_information_dialog_show (void);
@@ -48,9 +49,10 @@ gboolean uc_application_treeview_get_selected_iter (const GtkTreeView
 						    * tv, GtkTreeIter * iter);
 void uc_application_build_url_treeview (void);
 void uc_application_build_projects_treeview (void);
-void uc_application_main_tree_display_status (const guint link_status);
-void uc_application_main_tree_display_type (const UCLinkType link_type);
-void uc_application_main_tree_display_protocol (const gchar * proto);
+void uc_application_reset_menu_protocols (void);
+void uc_application_reset_menu_status (void);
+void uc_application_reset_menu_types (void);
+void uc_application_main_tree_apply_filters (const gchar *wname);
 void uc_application_main_tree_display_all (void);
 void uc_application_main_tree_collapse_all (void);
 void uc_application_main_tree_expand_all (void);
