@@ -69,7 +69,6 @@ static void uc_bookmarks_reassign_parents (GList * list,
 
 
 static sqlite3 *sqlite3_cnx = NULL;
-static guint depth = 0;
 
 static GList *uc_bookmarks_firefox_get_content (void);
 static gint uc_bookmarks_firefox_cb (gpointer data, gint argc,
@@ -92,6 +91,8 @@ static void uc_bookmarks_googlechrome_delete_item (JsonArray *array,
 static JsonParser *uc_bookmarks_googlechrome_doc = NULL;
 #endif
 
+static guint depth = 0;
+
 // XBEL
 static xmlDocPtr uc_bookmarks_xbel_doc = NULL;
 
@@ -317,7 +318,7 @@ uc_bookmarks_save_changes (void)
       {
         uc_application_dialog_show (
           _("The filename is not in a correct format.\n"
-            "<b>Nothing has been done</>."), GTK_MESSAGE_ERROR);
+            "<b>Nothing has been done</b>."), GTK_MESSAGE_ERROR);
         g_free (filename), filename = NULL;
         return GTK_RESPONSE_CANCEL;
       }
