@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2002-2005 
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,9 +23,15 @@
 
 #include "general.h"
 
+void uc_bookmarks_free (void);
+UCBookmarksType uc_bookmarks_guess_type (const gchar *file);
 gint uc_bookmarks_save_changes (void);
-void uc_bookmarks_delete_link (const guint32 id);
+void uc_bookmarks_delete_bad_links (GList *list);
+void uc_bookmarks_delete_link (UCLinkProperties *prop);
+gboolean uc_bookmarks_format_is_googlechrome (const gchar * file);
+gboolean uc_bookmarks_format_is_firefox (const gchar *file);
 gboolean uc_bookmarks_format_is_xbel (const gchar * file);
+gboolean uc_bookmarks_format_is_opera (const gchar * file);
 void uc_bookmarks_begin_check (void);
 
 #endif
