@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2002-2009
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,180 @@
 
 #include "callbacks.h"
 
+
+void
+on_settings_cookies_toggled_cb (GtkToggleButton * button, gpointer user_data)
+{
+  if (strcmp (gtk_widget_get_name (GTK_WIDGET (button)),
+              "sd_radio_cookies_accept") == 0)
+    WSENS ("sd_frame_alerts", TRUE);
+  else
+    WSENS ("sd_frame_alerts", FALSE);
+}
+
+
+void
+on_settings_w3c_toggled_cb (GtkToggleButton * button, gpointer user_data)
+{
+  WSENS ("sd_notebook_w3c",
+	 gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)));
+}
+
+
+void
+on_settings_security_toggled_cb (GtkToggleButton * button, gpointer user_data)
+{
+  WSENS ("sd_notebook_security",
+	 gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)));
+}
+
+
+gboolean on_widget_deactivate_brelease_event (GtkWidget *widget,
+                                              GdkEvent *event,
+                                              gpointer user_data)
+{
+  return (event->type == GDK_BUTTON_RELEASE);
+}
+
+
+gboolean on_display_checkbox_status_event (GtkWidget *widget, GdkEvent *event,
+                                           gpointer user_data)
+{
+  const gchar *wname = NULL;
+  UCDisplayStatus status;
+
+
+  if (event->type == GDK_BUTTON_RELEASE)
+  {
+    wname = gtk_widget_get_name (widget);
+
+    if (strcmp (wname, "mwm_display_goodlinks") == 0)
+      status = UC_DISPLAY_STATUS_GOODLINKS;
+    else if (strcmp (wname, "mwm_display_badlinks") == 0)
+      status = UC_DISPLAY_STATUS_BADLINKS;
+    else if (strcmp (wname, "mwm_display_timeouts") == 0)
+      status = UC_DISPLAY_STATUS_TIMEOUTS;
+    else if (strcmp (wname, "mwm_display_malformedlinks") == 0)
+      status = UC_DISPLAY_STATUS_MALFORMEDLINKS;
+    else if (strcmp (wname, "mwm_display_security_alerts") == 0)
+      status = UC_DISPLAY_STATUS_SECURITY_ALERTS;
+    else if (strcmp (wname, "mwm_display_w3c_alerts") == 0)
+      status = UC_DISPLAY_STATUS_W3C_ALERTS;
+    else
+      g_assert_not_reached ();
+
+    if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget)))
+    {
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget), TRUE);
+      uc_application_reset_menu_types ();
+      uc_application_reset_menu_protocols ();
+      UC_DISPLAY_STATUS_SET (status);
+    }
+    else
+    {
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget), FALSE);
+      UC_DISPLAY_STATUS_UNSET (status);
+    }
+  
+    uc_application_main_tree_apply_filters ("mwm_link_status");
+
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
+
+gboolean on_display_checkbox_type_event (GtkWidget *widget, GdkEvent *event,
+                                         gpointer user_data)
+{
+  const gchar *wname = NULL;
+  UCDisplayType type;
+
+
+  if (event->type == GDK_BUTTON_RELEASE)
+  {
+    wname = gtk_widget_get_name (widget);
+
+    if (strcmp (wname, "mwm_document_type") == 0)
+      type = UC_DISPLAY_TYPE_HREF;
+    else if (strcmp (wname, "mwm_image_type") == 0)
+      type = UC_DISPLAY_TYPE_IMAGE;
+    else if (strcmp (wname, "mwm_frame_type") == 0)
+      type = UC_DISPLAY_TYPE_FRAME;
+    else if (strcmp (wname, "mwm_email_type") == 0)
+      type = UC_DISPLAY_TYPE_EMAIL;
+    else if (strcmp (wname, "mwm_stylesheet_type") == 0)
+      type = UC_DISPLAY_TYPE_CSS;
+    else
+      g_assert_not_reached ();
+
+    if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget)))
+    {
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget), TRUE);
+      uc_application_reset_menu_status ();
+      uc_application_reset_menu_protocols ();
+      UC_DISPLAY_TYPE_SET (type);
+    }
+    else
+    {
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget), FALSE);
+      UC_DISPLAY_TYPE_UNSET (type);
+    }
+  
+    uc_application_main_tree_apply_filters ("mwm_link_type");
+
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
+
+gboolean on_display_checkbox_protocol_event (GtkWidget *widget, GdkEvent *event,
+                                             gpointer user_data)
+{
+  const gchar *wname = NULL;
+  UCDisplayProto proto;
+
+
+  if (event->type == GDK_BUTTON_RELEASE)
+  {
+    wname = gtk_widget_get_name (widget);
+
+    if (strcmp (wname, "mwm_http_protocol") == 0)
+      proto = UC_DISPLAY_PROTO_HTTP;
+    else if (strcmp (wname, "mwm_file_protocol") == 0)
+      proto = UC_DISPLAY_PROTO_FILE;
+    else if (strcmp (wname, "mwm_https_protocol") == 0)
+      proto = UC_DISPLAY_PROTO_HTTPS;
+    else if (strcmp (wname, "mwm_ftp_protocol") == 0)
+      proto = UC_DISPLAY_PROTO_FTP;
+    else
+      g_assert_not_reached ();
+
+    if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget)))
+    {
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget), TRUE);
+      uc_application_reset_menu_status ();
+      uc_application_reset_menu_types ();
+      UC_DISPLAY_PROTO_SET (proto);
+    }
+    else
+    {
+      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget), FALSE);
+      UC_DISPLAY_PROTO_UNSET (proto);
+    }
+  
+    uc_application_main_tree_apply_filters ("mwm_protocol");
+
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
+
 void
 on_search_close_clicked (GtkButton * button, gpointer user_data)
 {
@@ -70,97 +244,13 @@ on_about_activate (GtkMenuItem * menuitem, gpointer user_data)
   uc_application_about_dialog_show ();
 }
 
+
 void
 on_settings_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
   uc_application_settings_dialog_show ();
 }
 
-void
-on_display_badlinks_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_status (UC_CHECK_DISPLAY_BADLINKS);
-}
-
-void
-on_display_goodlinks_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_status (UC_CHECK_DISPLAY_GOODLINKS);
-}
-
-void
-on_display_security_alerts_activate (GtkMenuItem * menuitem,
-				     gpointer user_data)
-{
-  uc_application_main_tree_display_status (UC_CHECK_DISPLAY_SECURITY_ALERTS);
-}
-
-void
-on_display_w3c_alerts_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_status (UC_CHECK_DISPLAY_W3C_ALERTS);
-}
-
-void
-on_display_documents_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_type (LINK_TYPE_HREF);
-}
-
-void
-on_display_images_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_type (LINK_TYPE_IMAGE);
-}
-
-void
-on_display_stylesheets_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_type (LINK_TYPE_CSS);
-}
-
-void
-on_display_frames_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_type (LINK_TYPE_FRAME);
-}
-
-void
-on_display_emails_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_type (LINK_TYPE_EMAIL);
-}
-
-void
-on_display_malformedlinks_activate (GtkMenuItem * menuitem,
-				    gpointer user_data)
-{
-  uc_application_main_tree_display_status (UC_CHECK_DISPLAY_MALFORMEDLINKS);
-}
-
-void
-on_display_timeouts_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_status (UC_CHECK_DISPLAY_TIMEOUTS);
-}
-
-void
-on_display_http_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_protocol (UC_PROTOCOL_HTTP);
-}
-
-void
-on_display_https_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_protocol (UC_PROTOCOL_HTTPS);
-}
-
-void
-on_display_ftp_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-  uc_application_main_tree_display_protocol (UC_PROTOCOL_FTP);
-}
 
 void
 on_display_all_activate (GtkMenuItem * menuitem, gpointer user_data)
@@ -259,6 +349,7 @@ on_project_list_mouse_clicked (GtkWidget * widget, GdkEventButton * event,
 void
 on_bt_cancel_progress_dialog_clicked (GtkButton * button, gpointer user_data)
 {
+  uc_application_progress_dialog_set_modal (TRUE);
   uc_check_cancel_set_value (TRUE);
 }
 
@@ -373,7 +464,59 @@ on_new_instance_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_report_export_html_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-  uc_report_export (UC_EXPORT_HTML);
+  uc_report_export (UC_EXPORT_HTML, NULL, UC_EXPORT_LIST_NORMAL);
+}
+
+void
+on_bt_export_csv_similar_links_clicked (GtkButton * button, gpointer user_data)
+{
+  UCLinkProperties *prop = NULL;
+  gint32 id = 0;
+
+
+  id = uc_check_treeview_get_selected_row_id ();
+  if (id < 0)
+    return;
+
+  prop = uc_lists_checked_links_lookup_by_uid (id);
+
+  uc_report_export (UC_EXPORT_CSV, prop->similar_links_parents,
+                    UC_EXPORT_LIST_SIMPLE);
+}
+
+void
+on_bt_export_csv_page_links_clicked (GtkButton * button, gpointer user_data)
+{
+  UCLinkProperties *prop = NULL;
+  gint32 id = 0;
+
+
+  id = uc_check_treeview_get_selected_row_id ();
+  if (id < 0)
+    return;
+
+  prop = uc_lists_checked_links_lookup_by_uid (id);
+
+  uc_report_export (UC_EXPORT_CSV, prop->all_links, UC_EXPORT_LIST_SIMPLE);
+}
+
+void
+on_report_export_csv_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+  uc_report_export (UC_EXPORT_CSV, uc_lists_checked_links_get (),
+                    UC_EXPORT_LIST_NORMAL);
+}
+
+void on_page_information_dialog_switch_page (GtkNotebook *notebook,
+                                             GtkNotebookPage *page,
+                                             guint page_num,
+                                             gpointer user_data) 
+{
+  // Set visible "CSV export" button if we ar on "Links" page
+  if (page_num == 1)
+    gtk_widget_show (WGET ("bt_page_information_dialog_export_csv"));
+  else
+    gtk_widget_hide (WGET ("bt_page_information_dialog_export_csv"));
 }
 
 void
@@ -561,11 +704,12 @@ on_new_search_button_clicked (GtkButton * button, gpointer user_data)
 void
 on_clear_project_history_clicked (GtkButton * button, gpointer user_data)
 {
-  gnome_entry_clear_history (GNOME_ENTRY (gnome_entry_new ("web_project")));
-  gnome_entry_clear_history (GNOME_ENTRY
-			     (gnome_entry_new ("bookmarks_project")));
-  gnome_entry_clear_history (GNOME_ENTRY
-			     (gnome_entry_new ("local_file_project")));
+  gnome_entry_clear_history (
+    GNOME_ENTRY (gnome_entry_new ("web_project")));
+  gnome_entry_clear_history (
+    GNOME_ENTRY (gnome_entry_new ("bookmarks_project")));
+  gnome_entry_clear_history (
+    GNOME_ENTRY (gnome_entry_new ("local_file_project")));
 }
 
 void
@@ -574,6 +718,12 @@ on_clear_search_history_clicked (GtkButton * button, gpointer user_data)
   gnome_entry_clear_history (GNOME_ENTRY (gnome_entry_new ("search")));
 }
 
+void
+on_clear_export_history_clicked (GtkButton * button, gpointer user_data)
+{
+  gnome_entry_clear_history (GNOME_ENTRY (gnome_entry_new ("export_path")));
+}
+
 void
 on_new_search_check_button_toggled (GtkToggleButton * togglebutton,
 				    gpointer user_data)
@@ -613,18 +763,59 @@ on_bt_ok_new_bookmarks_project_clicked (GtkButton * button,
     }
 }
 
+
+void
+on_delete_all_bad_links_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+  gint res = 0;
+
+
+  res = uc_application_dialog_yes_no_show (
+      _("All bookmarks referring to not found page will be removed.\n"
+        "<b>Do you want to continue</b>?"), GTK_MESSAGE_QUESTION);
+  if (res != GTK_RESPONSE_YES)
+    return;
+
+  uc_application_main_tree_display_all ();
+  gtk_tree_view_expand_all (treeview);
+
+  uc_bookmarks_delete_bad_links (uc_lists_checked_links_get ());
+  uc_project_set_save_bookmarks (TRUE);
+
+  uc_application_main_tree_display_all ();
+  gtk_tree_view_expand_all (treeview);
+}
+
+
 void
 on_delete_link_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
   gint32 id = 0;
+  gint res = 0;
+  GtkTreeIter iter;
+  UCLinkProperties *prop = NULL;
+
 
   id = uc_check_treeview_get_selected_row_id ();
   if (id > 0)
-    uc_bookmarks_delete_link (id);
+  {
+    res = uc_application_dialog_yes_no_show (
+        _("Selected link will be removed.\n"
+          "<b>Do you want to continue</b>?"), GTK_MESSAGE_QUESTION);
+    if (res != GTK_RESPONSE_YES)
+      return;
+
+    uc_application_treeview_get_selected_iter (treeview, &iter);
+    prop = uc_lists_checked_links_lookup_by_uid (id);
+
+    uc_bookmarks_delete_link (prop);
+    uc_project_set_save_bookmarks (TRUE);
+
+    gtk_tree_store_remove (treestore, &iter);
+  }
   else
-    uc_application_dialog_show (_
-				("Please, select a item."),
-				GTK_MESSAGE_WARNING);
+    uc_application_dialog_show (
+      _("Please, select a item."), GTK_MESSAGE_WARNING);
 }
 
 void
@@ -654,8 +845,9 @@ on_project_properties_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_menu_refresh_all_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-  if (uc_project_get_bookmarks_file ())
-    g_warning ("function not yet implemented!");	/* FIXME */
+  // FIXME
+  if (uc_project_get_check_is_bookmarks ())
+    g_warning ("function not yet implemented!");
   else
     uc_web_site_refresh_all ();
 }
@@ -669,9 +861,8 @@ on_menu_refresh_branch_activate (GtkMenuItem * menuitem, gpointer user_data)
   if (id > 0)
     uc_web_site_refresh_branch (id);
   else
-    uc_application_dialog_show (_
-				("Please, select a item."),
-				GTK_MESSAGE_WARNING);
+    uc_application_dialog_show (_("Please, select a item."),
+                                GTK_MESSAGE_WARNING);
 }
 
 void
@@ -683,9 +874,8 @@ on_menu_refresh_link_activate (GtkMenuItem * menuitem, gpointer user_data)
   if (id > 0)
     uc_web_site_refresh_link (id);
   else
-    uc_application_dialog_show (_
-				("Please, select a item."),
-				GTK_MESSAGE_WARNING);
+    uc_application_dialog_show (_("Please, select a item."),
+                                GTK_MESSAGE_WARNING);
 }
 
 void
@@ -708,7 +898,7 @@ on_bt_ok_open_project_clicked (GtkButton * button, gpointer user_data)
     }
   else
     uc_application_dialog_show (_("Please, select a project."),
-				GTK_MESSAGE_WARNING);
+                                GTK_MESSAGE_WARNING);
 }
 
 void
