@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2002-2010
+ * Copyright (C) 2002-2011
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -160,7 +160,7 @@ uc_check_html_is_valid (const gchar * buffer)
   if ((tidy = uc_uctidy_new ()))
     {
       ret = (uc_uctidy_validate (tidy, buffer) == 0);
-      uc_uctidy_free (tidy);
+      uc_uctidy_free (&tidy);
     }
 #endif
 
@@ -905,7 +905,7 @@ uc_check_url_get_content (UCLinkProperties * prop,
   /* get HTTP response */
   response =
     uc_server_get_response (prop->protocol, hostname, atoi (prop->port),
-			    request, FALSE);
+			    request, FALSE, NULL);
   g_free (request), request = NULL;
 
   /* exit if no result */
@@ -1076,7 +1076,7 @@ uc_check_url_get_header (UCLinkProperties * prop)
         "%s"
         "%s"
         "%s"
-        "\r\n",
+        "Accept: */*\r\n\r\n",
         uri,
         UC_USER_AGENT, prop->h_name,
         (uc_project_get_auth_line ())?uc_project_get_auth_line ():"",
@@ -1091,7 +1091,7 @@ uc_check_url_get_header (UCLinkProperties * prop)
   /* get response */
   array =
     uc_server_get_response (prop->protocol, prop->h_name, atoi (prop->port),
-			    request, TRUE);
+			    request, TRUE, &prop->ip_addr);
   g_free (request), request = NULL;
 
   /* exit if no result */
@@ -1769,10 +1769,10 @@ uc_check_get_virii (UCLinkProperties * prop)
 
   path = uc_utils_convert_uid2file (prop->uid);
 
-  if ((clam = uc_ucclam_new ()))
+  if ((clam = uc_ucclam_new (NULL)))
     {
       ret = uc_ucclam_scan (clam, path, &prop->virname);
-      uc_ucclam_free (clam), clam = NULL;
+      uc_ucclam_free (&clam);
     }
 
   g_free (path), path = NULL;
@@ -1803,7 +1803,7 @@ uc_check_get_w3c_css_validate (UCLinkProperties * prop)
   if ((croco = uc_uccroco_new ()))
     {
       ret = uc_uccroco_validate (croco, buffer);
-      uc_uccroco_free (croco), croco = NULL;
+      uc_uccroco_free (&croco);
     }
 
   g_free (buffer), buffer = NULL;
@@ -1835,7 +1835,7 @@ uc_check_get_w3c_html_validate (UCLinkProperties * prop)
   if ((tidy = uc_uctidy_new ()))
     {
       ret = (uc_uctidy_validate (tidy, buffer) == 0);
-      uc_uctidy_free (tidy), tidy = NULL;
+      uc_uctidy_free (&tidy);
     }
 
   g_free (buffer), buffer = NULL;
@@ -2071,6 +2071,7 @@ uc_check_link_properties_node_new (void)
   prop->url = NULL;
   prop->normalized_url = NULL;
   prop->label = NULL;
+  prop->ip_addr = NULL;
   prop->h_name = NULL;
   prop->port = NULL;
   prop->path = NULL;
