@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2002-2005 
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -52,21 +52,6 @@ enum
   N_COLUMNS
 };
 
-/* struct to point on the current url or host elements
- * (for timeouts callback) */
-struct _UCCurrentItem
-{
-  gchar *current_host;
-  gchar *current_path;
-  UCHTMLTag *tag;
-  GList *list_ptr;
-  UCLinkProperties *parent;
-  xmlNodePtr xml_node;
-  gchar *url;
-  gchar *label;
-}
-currentItem;
-
 
 /*
  * enum for return code of the href properties
@@ -85,6 +70,8 @@ typedef enum
 }
 UCHTTPCheckReturn;
 
+
+GHashTable *uc_check_url_get_header (UCLinkProperties * prop);
 gboolean uc_check_content_type_w3c_accepted (const gchar * type,
 					     gchar * path,
 					     gchar * content_type);
@@ -114,9 +101,8 @@ gchar *uc_check_get_link_type_for_icon (const gchar * proto);
 GdkPixbuf *uc_check_get_link_type_icon (const UCLinkType link_type,
 					const gchar * proto);
 void uc_check_currentitem_init (UCLinkProperties * parent,
-				gchar * current_host, gchar * current_path,
-				UCHTMLTag * tag, gchar * url, gchar * label,
-				const xmlNodePtr * node);
+                                gchar * current_host, UCHTMLTag * tag,
+                                gchar * url, gboolean is_first);
 void uc_check_wait (void);
 gboolean uc_check_link_already_checked_with_insert (UCLinkProperties * prop,
 						    gchar * url);
@@ -147,14 +133,7 @@ void uc_check_bookmarks_begin (void);
 void uc_check_cancel_set_value (const gboolean value);
 void uc_check_ignore_item_set_value (const gboolean value);
 void uc_check_display_items_active_all (void);
-void uc_check_display_list (GList * list, gchar * path);
-void uc_check_display_list_with_status (GList * list, GtkTreeIter iter,
-					const guint view_type);
-void uc_check_display_list_with_type (GList * list, GtkTreeIter iter,
-				      const UCLinkType link_type);
-void
-uc_check_display_list_with_protocol (GList * list, GtkTreeIter iter,
-				     const gchar * proto);
+void uc_check_display_list (GList * list, gchar * path, GtkTreeIter iter);
 void uc_check_reset (void);
 void uc_check_alarm_callback (const int dum);
 void uc_check_link_view_source (void);
