@@ -100,6 +100,7 @@ struct _UCConn
   UCTcpState tcp_state;
   UCTcpStatus tcp_status;
   gchar *hostname;
+  gchar **ip_addr;
   guint port;
   GArray *array;
   gchar *request;
@@ -138,7 +139,7 @@ static void *connect_thread (void *data);
 static void *read_thread (void *data);
 static UCConn *uc_conn_new (const gchar * proto, gchar * host,
 			    guint port, gchar * buffer,
-			    gboolean header_request);
+			    gboolean header_request, gchar **ip);
 static void uc_conn_disconnect (UCConn * conn);
 static void uc_conn_free (UCConn **conn);
 static UCTcpStatus connect_nonblock (const gint soc, struct sockaddr *addr,
@@ -197,7 +198,7 @@ uc_conn_free (UCConn **conn)
  */
 static UCConn *
 uc_conn_new (const gchar * proto, gchar * host, guint port, gchar * buffer,
-	     gboolean header_request)
+	     gboolean header_request, gchar **ip_addr)
 {
   UCConn *conn = NULL;
 
@@ -218,6 +219,9 @@ uc_conn_new (const gchar * proto, gchar * host, guint port, gchar * buffer,
   conn->array = g_array_new (FALSE, TRUE, 1);
   conn->request = buffer;
 
+  // To be fill during connection attempt
+  conn->ip_addr = ip_addr;
+
   if (strcmp (proto, UC_PROTOCOL_FTP) == 0)
   {
     conn->use_ftp = TRUE;
@@ -318,7 +322,7 @@ uc_conn_disconnect (UCConn * conn)
  */
 GArray *
 uc_server_get_response (const gchar * proto, gchar * host, const guint port,
-			gchar * buffer, gboolean header_request)
+			gchar * buffer, gboolean header_request, gchar **ip)
 {
   guint port_real = 0;
   gchar *host_real = NULL;
@@ -345,7 +349,8 @@ uc_server_get_response (const gchar * proto, gchar * host, const guint port,
   }
 
   // Connect
-  conn = uc_conn_new (proto, host_real, port_real, buffer, header_request);
+  conn = uc_conn_new (proto, host_real, port_real, buffer, header_request,
+                     ip);
   conn->thread_end = FALSE;
   pthread_create (&conn->thread_id, NULL, connect_thread, conn);
   pthread_detach (conn->thread_id);
@@ -768,6 +773,13 @@ connect_thread (void *data)
   else if ((*sock = socket (res->ai_family, res->ai_socktype,
                             res->ai_protocol)) >= 0)
   {
+    // Get IP addr if caller is OK for that (header request only)
+    if (conn->ip_addr)
+    {
+      struct sockaddr_in *sa = (struct sockaddr_in *) res->ai_addr;
+      *conn->ip_addr = g_strdup (inet_ntoa (sa->sin_addr));
+    }
+
     // Free getaddrinfo result at thread exit
     pthread_cleanup_push ((void *) freeaddrinfo, res);
 
