@@ -25,6 +25,6 @@
 void uc_conn_init (void);
 GArray *uc_server_get_response (const gchar * proto, gchar * host,
 				const guint port, gchar * buffer,
-				gboolean header_request);
+				gboolean header_request, gchar **ip);
 
 #endif
