@@ -795,6 +795,9 @@ GtkListStore *treestore_filter_domains;	/* rejected domains */
 GtkListStore *treestore_search;	/* result of the search */
 
 gboolean uc_refresh_page;
+#ifdef ENABLE_CLAMAV
+gboolean uc_init_clamav_done;
+#endif
 
 GdkPixbuf *security_alert_icon;
 GdkPixbuf *w3c_alert_icon;
@@ -1115,6 +1118,7 @@ struct _UCLinkProperties
   gchar *url;
   gchar *normalized_url;
   gchar *label;
+  gchar *ip_addr;
   gchar *protocol;
   gchar *h_name;
   gchar *port;
