@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2006
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -551,7 +551,6 @@ uc_html_parser_parse (GList * tags, htmlNodePtr cur)
 	      g_free (tmp), tmp = NULL;
 	    }
 
-	  // FIXME Do not add URL if it was already checked
 	  if (tag->type != LINK_TYPE_BASE_HREF)
 	    tags = g_list_append (tags, tag);
 	  else
@@ -636,10 +635,10 @@ uc_html_parser_node_new (void)
 }
 
 void
-uc_html_parser_node_free (UCHTMLTag * tag)
+uc_html_parser_node_free (UCHTMLTag **tag)
 {
-  g_free (tag->label), tag->label = NULL;
-  g_free (tag->value), tag->value = NULL;
+  g_free ((*tag)->label), (*tag)->label = NULL;
+  g_free ((*tag)->value), (*tag)->value = NULL;
 
-  g_free (tag), tag = NULL;
+  g_free ((*tag)), (*tag) = NULL;
 }
