@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2005 
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,8 @@
 
 #include "general.h"
 
-void uc_html_parser_node_free (UCHTMLTag * tag);
+
+void uc_html_parser_node_free (UCHTMLTag **tag);
 GList *uc_html_parser_get_tags (gchar * buffer_orig);
 UCHTMLTag *uc_html_parser_node_new (void);
 GList *uc_css_parser_get_tags (gchar * buffer_orig);
