@@ -133,6 +133,8 @@ gboolean uc_project_get_security_checks (const gchar * type);
 gboolean uc_project_get_w3c_checks (const gchar * type);
 gboolean uc_project_get_export_labels (void);
 gboolean uc_project_get_export_numbering (void);
+gboolean uc_project_get_export_external (void);
+gboolean uc_project_get_export_ip (void);
 gboolean uc_project_get_debug_mode (void);
 gboolean uc_project_get_dump_properties (void);
 guint uc_project_get_tooltips_delay (void);
@@ -193,6 +195,8 @@ void uc_project_set_security_checks (const gchar * type,
 void uc_project_set_w3c_checks (const gchar * type, const gboolean value);
 void uc_project_set_export_labels (const gboolean value);
 void uc_project_set_export_numbering (const gboolean value);
+void uc_project_set_export_external(const gboolean value);
+void uc_project_set_export_ip (const gboolean value);
 void uc_project_set_debug_mode (const gboolean value);
 void uc_project_set_dump_properties (const gboolean value);
 void uc_project_set_tooltips_delay (const guint value);
