@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2005 
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -128,7 +128,7 @@ uc_tooltips_main_cb (gpointer data)
       uc_tooltips_main_get_frozen () ||
       uc_lists_checked_links_is_empty () ||
       (uc_project_get_url () == NULL &&
-       uc_project_get_bookmarks_file () == NULL))
+       !uc_project_get_check_is_bookmarks ()))
     return TRUE;
 
   uc_tooltips_main_get_mouse_coord (&x, &y);
