@@ -33,9 +33,9 @@ struct _UCClam
   struct cl_engine *engine;
 };
 
-UCClam *uc_ucclam_new (void);
+UCClam *uc_ucclam_new (gchar **error);
 gboolean uc_ucclam_scan (UCClam * clam, const gchar * path, gchar ** virname);
-void uc_ucclam_free (UCClam * clam);
+void uc_ucclam_free (UCClam ** clam);
 
 #endif
 #endif
