@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2005 
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,13 +20,14 @@
 
 #include "utils.h"
 #include "project.h"
-#include "check.h"
 
 #include "url.h"
 
+
 static gchar *uc_url_get_absolute (gchar * url);
 static gboolean uc_url_is_relative (const gchar * url);
 
+
 /**
  * uc_url_add_slash:
  * @url: a URL.
@@ -44,6 +45,7 @@ uc_url_add_slash (const gchar * url)
     g_strconcat (url, "/", NULL) : g_strdup (url);
 }
 
+
 /**
  * uc_url_is_faked:
  * @prop: A #UCLinkProperties object.
@@ -63,6 +65,7 @@ uc_url_is_faked (UCLinkProperties * prop, UCHTMLTag * tag)
   gchar *tmp = NULL;
   gchar *port = NULL;
 
+
   if (prop == NULL || prop->header == NULL)
     return ret;
 
@@ -70,16 +73,17 @@ uc_url_is_faked (UCLinkProperties * prop, UCHTMLTag * tag)
   if (new_location == NULL)
     new_location = g_hash_table_lookup (prop->header, UC_CONTENT_LOCATION);
 
-  port = (!strcmp (prop->port, UC_URL_DEFAULT_SSL_PORT) ||
-	  !strcmp (prop->port, UC_URL_DEFAULT_PORT)) ?
-    g_strdup ("") : g_strconcat (":", prop->port, NULL);
-
-  /* if new_location is ok, go one, else
-   * continue to default */
+  // If new_location is ok, go one, else continue to default
   if (new_location != NULL)
     {
       ret = TRUE;
 
+      if (strcmp (prop->port, UC_URL_DEFAULT_SSL_PORT) == 0 ||
+          strcmp (prop->port, UC_URL_DEFAULT_PORT) == 0)
+        port = g_strdup ("");
+      else
+        port = g_strconcat (":", prop->port, NULL);
+
       concat =
 	(!(uc_utils_memcasecmp (new_location, UC_PROTOCOL_HTTP) ||
 	   uc_utils_memcasecmp (new_location, UC_PROTOCOL_HTTPS)
@@ -90,7 +94,7 @@ uc_url_is_faked (UCLinkProperties * prop, UCHTMLTag * tag)
       if (*new_location == '/')
 	tag->value =
 	  g_strconcat (prop->protocol, "://",
-		       prop->h_name, port, new_location, NULL);
+                       prop->h_name, port, new_location, NULL);
       else
 	{
 	  tmp = strrchr (prop->path, '/');
@@ -119,26 +123,29 @@ uc_url_is_faked (UCLinkProperties * prop, UCHTMLTag * tag)
 	    tag->value = g_strconcat ("/", new_location, NULL);
 	}
 
-      uc_utils_debug
-	("              Real location: \"%s\" for the following link:\n",
-	 tag->value);
-    }
+      g_free (port), port = NULL;
 
-  g_free (port), port = NULL;
+      uc_utils_debug (
+        "              Real location: \"%s\" for the following link:\n",
+        (tag->value)?tag->value:"");
+    }
 
   return ret;
 }
 
+
 static gboolean
 uc_url_is_relative (const gchar * url)
 {
   const gchar *tmp = NULL;
 
+
   return (url != NULL &&
 	  (tmp = strstr (url, "./")) != NULL &&
 	  !g_ascii_isalpha (*(tmp - 1)));
 }
 
+
 /**
  * uc_url_get_absolute:
  * @url: A complete URI or just a path.
@@ -163,21 +170,21 @@ uc_url_get_absolute (gchar * url)
   gchar *ret = NULL;
   gsize inc = 0;
 
+
   g_return_val_if_fail (url != NULL, g_strdup (""));
 
   if (strstr (url, "./") == NULL)
     return g_strdup (url);
 
-  /* if it is a path, it must not begin with more than
-   * on slash */
+  // If it is a path, it must not begin with more than on slash
   while (url[1] && url[1] == '/')
     url++;
 
   if ((p2 = strstr (url, "../")) != NULL)
     {
       while (*p2 == '.' || *p2 == '/')
-	p2--;
-      p2++;
+	--p2;
+      ++p2;
 
       p1 = url;
       begin = uc_utils_strdup_delim (p1, p2);
@@ -218,10 +225,10 @@ uc_url_get_absolute (gchar * url)
     ret = g_strdup (url);
 
   p1 = ret;
-  while ((p1 = strstr ((char *) p1, "./")) != NULL && uc_url_is_relative (p1))
+  while ((p1 = strstr ((gchar *) p1, "./")) != NULL && uc_url_is_relative (p1))
     {
       if (*(p1 - 1) == '.')
-	p1--, inc = 3;
+	--p1, inc = 3;
       else
 	inc = 2;
 
@@ -232,6 +239,7 @@ uc_url_get_absolute (gchar * url)
   return ret;
 }
 
+
 /**
  * uc_url_normalize:
  * @current_host: The current host.
@@ -254,42 +262,50 @@ uc_url_normalize (const gchar * current_host,
   gchar *normalized_url = NULL;
   gchar *tmp = NULL;
 
+
   protocol = uc_url_get_protocol (url);
 
-  if (!strcmp (protocol, UC_PROTOCOL_FILE) ||
-      !strcmp (protocol, UC_PROTOCOL_MAILTO))
-    {
-      g_free (protocol), protocol = NULL;
-      return g_strdup (url);
-    }
+  if (strcmp (protocol, UC_PROTOCOL_FILE) == 0 ||
+      strcmp (protocol, UC_PROTOCOL_MAILTO) == 0)
+  {
+    g_free (protocol), protocol = NULL;
+    return g_strdup (url);
+  }
 
-  if (uc_url_parse (current_host, current_path, url, &host,
-		    &port, &path, &args))
-    {
-      if (path[strlen (path) - 1] == '/')
-	path[strlen (path) - 1] = '\0';
+  if (uc_url_parse (current_host, current_path, url,
+                    &host, &port, &path, &args))
+  {
+    if (path[strlen (path) - 1] == '/')
+      path[strlen (path) - 1] = '\0';
 
-      tmp = (!strcmp (port, UC_URL_DEFAULT_SSL_PORT) ||
-	     !strcmp (port, UC_URL_DEFAULT_PORT)) ?
-	g_strdup ("") : g_strconcat (":", port, NULL);
+    if (strcmp (port, UC_URL_DEFAULT_SSL_PORT) == 0 ||
+        strcmp (port, UC_URL_DEFAULT_PORT) == 0)
+      tmp = g_strdup ("");
+    else
+      tmp = g_strconcat (":", port, NULL);
 
-      normalized_url =
-	g_strconcat (protocol, "://", host, tmp, path, args, NULL);
+    normalized_url = 
+      g_strconcat (protocol, "://", host, tmp, path, args, NULL);
 
-      g_free (tmp), tmp = NULL;
-      g_free (host), host = NULL;
-      g_free (port), port = NULL;
-      g_free (path), path = NULL;
-      g_free (args), args = NULL;
-    }
+    g_free (tmp), tmp = NULL;
+  }
   else
     normalized_url = g_strdup (url);
 
+  if (host || port || path || args)
+  {
+    g_free (host), host = NULL;
+    g_free (port), port = NULL;
+    g_free (path), path = NULL;
+    g_free (args), args = NULL;
+  }
+
   g_free (protocol), protocol = NULL;
 
   return normalized_url;
 }
 
+
 /**
  * uc_url_add_protocol:
  * @proto: The protocol to add.
@@ -302,12 +318,11 @@ uc_url_normalize (const gchar * current_host,
 gchar *
 uc_url_add_protocol (const gchar * proto, const gchar * host)
 {
-  if ((strstr (host, "://")))
-    return g_strdup (host);
-
-  return g_strconcat (proto, "://", host, NULL);
+  return (strstr (host, "://") != NULL) ?
+    g_strdup (host) : g_strconcat (proto, "://", host, NULL);
 }
 
+
 /**
  * uc_url_get_hostname:
  * @current_host: The current host.
@@ -321,21 +336,33 @@ uc_url_add_protocol (const gchar * proto, const gchar * host)
 gchar *
 uc_url_get_hostname (const gchar * current_host, const gchar * url)
 {
-  const char *b = NULL;
-  const char *e = NULL;
+  const gchar *b = NULL;
+  const gchar *e = NULL;
+  gchar *ret = NULL;
 
-  if (!url || !(b = strstr (url, "://")))
-    return (current_host) ? g_strdup (current_host) :
-      (uc_project_get_type () == UC_PROJECT_TYPE_LOCAL_FILE) ?
-      g_strdup ("") : NULL;;
 
-  b += 3;
-  if (!(e = strpbrk (b, ":/")))
-    return strdup (b);
+  if (url == NULL || (b = strstr (url, "://")) == NULL)
+  {
+    if (current_host != NULL)
+      ret = g_strdup (current_host);
+    else if (uc_project_get_type () == UC_PROJECT_TYPE_LOCAL_FILE)
+      ret = g_strdup ("");
+    else
+      ret = NULL;
+  }
+  else
+  {
+    b += 3;
+    if ((e = strpbrk (b, ":/")) == NULL)
+      ret =  g_strdup (b);
+    else
+      ret = uc_utils_strdup_delim (b, e);
+  }
 
-  return uc_utils_strdup_delim (b, e);
+  return ret;
 }
 
+
 /**
  * uc_url_parse:
  * @current_host: The current host.
@@ -363,13 +390,16 @@ uc_url_parse (const gchar * current_host,
   gchar *real_cpath = NULL;
   gchar *project_host = NULL;
   gchar *url = NULL;
+  gsize url_len = 0;
   gboolean ret = TRUE;
 
+
   url = uc_utils_replace (rurl, "&amp;", "&");
+  url_len = strlen (url);
   project_host = uc_project_get_current_host ();
 
-  if (!strcmp (url, "..") ||
-      (strlen (url) > 3 && !strcmp (&url[strlen (url) - 3], "/..")))
+  if (strcmp (url, "..") == 0 ||
+      (url_len > 3 && strcmp (&url[url_len - 3], "/..") == 0))
     {
       gchar *tmp = NULL;
 
@@ -535,6 +565,7 @@ uc_url_parse (const gchar * current_host,
   return ret;
 }
 
+
 /**
  * uc_url_get_port:
  * @url: The URI.
@@ -548,24 +579,38 @@ uc_url_get_port (const gchar * url)
 {
   gchar *p1 = NULL;
   gchar *p2 = NULL;
+  gchar *ret = NULL;
 
-  if (!(p1 = strstr (url, "://")))
-    return g_strdup (UC_URL_DEFAULT_PORT);
 
-  p1 += 3;
-  if (!(p2 = strchr (p1, ':')))
-    return g_strdup (((!g_ascii_strncasecmp (url, UC_PROTOCOL_HTTPS,
-					     strlen (UC_PROTOCOL_HTTPS))) ?
-		      UC_URL_DEFAULT_SSL_PORT : UC_URL_DEFAULT_PORT));
-  p2++;
-
-  p1 = p2;
-  while (isdigit ((int) *p2))
-    p2++;
-
-  return uc_utils_strdup_delim (p1, p2);
+  if ((p1 = strstr (url, "://")) == NULL)
+    ret = g_strdup (UC_URL_DEFAULT_PORT);
+  else
+  {
+    p1 += 3;
+    if ((p2 = strchr (p1, ':')) == NULL)
+    {
+      if (g_ascii_strncasecmp (url, UC_PROTOCOL_HTTPS,
+                               strlen (UC_PROTOCOL_HTTPS)) == 0)
+        ret = g_strdup (UC_URL_DEFAULT_SSL_PORT);
+      else
+        ret = g_strdup (UC_URL_DEFAULT_PORT);
+    }
+    else
+    {
+      ++p2;
+  
+      p1 = p2;
+      while (isdigit ((gint) *p2))
+        ++p2;
+  
+      ret = uc_utils_strdup_delim (p1, p2);
+    }
+  }
+  
+  return ret;
 }
 
+
 /**
  * uc_url_get_protocol:
  * @url: The URI.
@@ -582,22 +627,27 @@ uc_url_get_protocol (const gchar * url)
   gchar **split = NULL;
   gchar *ret = NULL;
 
-  /* search only for ":", and not "://" because we want also pseudo protocols
-   * like "mailto:" */
-  if (!strchr (url, ':'))
-    ret =
-      (!strcmp (uc_project_get_current_port (), UC_URL_DEFAULT_SSL_PORT)) ?
-      g_strdup (UC_PROTOCOL_HTTPS) : g_strdup (UC_PROTOCOL_HTTP);
+
+  // Search only for ":", and not "://" because we want also pseudo protocols
+  // like "mailto:"
+  if (strchr (url, ':') == NULL)
+  {
+    if (strcmp (uc_project_get_current_port (), UC_URL_DEFAULT_SSL_PORT) == 0)
+      ret = g_strdup (UC_PROTOCOL_HTTPS);
+    else
+      ret = g_strdup (UC_PROTOCOL_HTTP);
+  }
   else
-    {
-      split = g_strsplit (url, ":", 0);
-      ret = g_utf8_strdown (split[0], -1);
-      g_strfreev (split), split = NULL;
-    }
+  {
+    split = g_strsplit (url, ":", 0);
+    ret = g_utf8_strdown (split[0], -1);
+    g_strfreev (split), split = NULL;
+  }
 
   return ret;
 }
 
+
 /**
  * uc_url_extract_url_from_local_path:
  * @path: The path from which to extract URL.
@@ -612,50 +662,47 @@ uc_url_extract_url_from_local_path (const gchar * path)
 {
   const gchar *begin = NULL;
 
-  if (!(begin = strstr (path, UC_PROTOCOL_HTTPS "://")) &&
-      !(begin = strstr (path, UC_PROTOCOL_HTTP "://")) &&
-      !(begin = strstr (path, UC_PROTOCOL_FTP "://")))
+
+  if ((begin = strstr (path, UC_PROTOCOL_HTTPS "://")) == NULL &&
+      (begin = strstr (path, UC_PROTOCOL_HTTP "://")) == NULL &&
+      (begin = strstr (path, UC_PROTOCOL_FTP "://")) == NULL)
     return NULL;
 
   return uc_utils_strdup_delim (begin, &path[strlen (path)]);
 }
 
+
 /**
  * uc_url_is_valid:
  * @url: The URI.
  * 
- * Check the validity of a given url.
+ * Quikly (loosly) check the validity of a given url.
  *
  * Returns: %TRUE if the given URI is valid.
  */
 gboolean
 uc_url_is_valid (const gchar * url)
 {
-  gchar *test = NULL;
-  gchar *host = NULL;
-  gchar *proto = NULL;
+  GURI *uri = NULL;
+  gchar *ip = NULL;
   gboolean ret = FALSE;
 
-  proto = uc_url_get_protocol (url);
-  if (!strcmp (proto, UC_PROTOCOL_FILE))
-    {
-      ret = TRUE;
-      goto end;
-    }
 
-  if ((!url) || (!strlen (url))
-      || (!(host = uc_url_get_hostname (NULL, url))))
-    goto end;
+  uri = gnet_uri_new (url);
 
-  if (!(test = uc_utils_get_ip (host)))
-    goto end;
+  if (uri->scheme != NULL &&
+      g_ascii_strcasecmp (uri->scheme, UC_PROTOCOL_FILE) == 0)
+    ret = TRUE;
+  else if (uri->hostname == NULL)
+    ret = FALSE;
+  else if (g_ascii_strcasecmp (uri->scheme, UC_PROTOCOL_HTTP) != 0 &&
+           g_ascii_strcasecmp (uri->scheme, UC_PROTOCOL_HTTPS) != 0 &&
+           g_ascii_strcasecmp (uri->scheme, UC_PROTOCOL_FTP) != 0)
+    ret = FALSE;
+  else if ((ret = ((ip = uc_utils_get_ip (uri->hostname)) != NULL)))
+    g_free (ip), ip = NULL;
 
-  ret = TRUE;
-
-end:
-  g_free (proto), proto = NULL;
-  g_free (host), host = NULL;
-  g_free (test), test = NULL;
+  gnet_uri_delete (uri);
 
   return ret;
 }
