@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2005 
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,8 +22,10 @@
 #include "check.h"
 #include "connection.h"
 #include "project.h"
+
 #include "utils.h"
 
+
 void
 uc_utils_clear_container (GtkContainer * container)
 {
@@ -372,7 +374,7 @@ uc_utils_http_atotm (const gchar * time_string)
   if (!time_string)
     return -1;
 
-  for (i = 0; i < UC_ARRAY_SIZE (time_formats); i++)
+  for (i = 0; i < G_N_ELEMENTS (time_formats); i++)
     if (uc_utils_check_date_end (strptime (time_string, time_formats[i], &t)))
       return uc_utils_mktime_from_utc (&t);
 
@@ -386,6 +388,8 @@ uc_utils_http_atotm (const gchar * time_string)
 /**
  * uc_utils_get_auth_fields:
  * @g: a #GladeXML object.
+ * @w_auth_user: GtkWidget containing auth user string 
+ * @w_auth_password: GtkWidget containing auth password string 
  * @auth_user: user will be store here.
  * @auth_password: password will be store here.
  * @auth_line: authentication line will be store here.
@@ -435,8 +439,8 @@ uc_utils_get_auth_fields (GladeXML * g,
 
 /**
  * uc_utils_build_auth_line:
- * @auth_user:
- * @auth_password:
+ * @auth_user: user
+ * @auth_password: password
  *
  * Build the line for basic authentication to pass to HTTP headers.
  * 
@@ -465,6 +469,7 @@ uc_utils_build_auth_line (const gchar * auth_user,
 
 }
 
+
 /**
  * uc_utils_get_meta_refresh_location:
  * @prop: A #UCLinkProperties node.
@@ -484,37 +489,40 @@ uc_utils_get_meta_refresh_location (UCLinkProperties * prop, UCHTMLTag * tag)
   gboolean ok = TRUE;
   gboolean ret = FALSE;
 
+
   if (prop == NULL || prop->metas == NULL)
     return FALSE;
 
   item = g_list_first (prop->metas);
   while (item != NULL && ok)
+  {
+    UCHTMLTag *meta = (UCHTMLTag *) item->data;
+
+
+    if (!g_ascii_strcasecmp (meta->label, "refresh") &&
+        meta->value[0] == '0')
     {
-      UCHTMLTag *meta = (UCHTMLTag *) item->data;
-
-      if (!g_ascii_strcasecmp (meta->label, "refresh")
-	  && meta->value[0] == '0')
-	{
-	  tmp = g_strsplit (meta->value, ";", -1);
-	  if (tmp[1] != NULL)
-	    {
-	      if ((p = strchr (tmp[1], '=')) && ++p)
-		{
-		  g_free (tag->value), tag->value = NULL;
-		  tag->value = g_strdup (p);
-		  ret = TRUE;
-		}
-	      ok = FALSE;
-	    }
-	  g_strfreev (tmp), tmp = NULL;
-	}
-
-      item = g_list_next (item);
+      tmp = g_strsplit (meta->value, ";", -1);
+      if (tmp[1] != NULL)
+      {
+        if ((p = strchr (tmp[1], '=')) && ++p)
+        {
+          g_free (tag->value), tag->value = NULL;
+          tag->value = g_strdup (p);
+          ret = TRUE;
+        }
+        ok = FALSE;
+      }
+      g_strfreev (tmp), tmp = NULL;
     }
 
+    item = g_list_next (item);
+  }
+
   return ret;
 }
 
+
 /**
  * uc_utils_to_utf8:
  * @data: String to proceed.
@@ -602,8 +610,7 @@ uc_utils_debug (const gchar * format, ...)
   vsnprintf (s, 2048, format, ap);
   va_end (ap);
 
-  g_print ("DEBUG: ");
-  g_print (s);
+  g_print ("DEBUG: %s", s);
 
   g_free (s), s = NULL;
 }
@@ -623,8 +630,10 @@ uc_utils_debug_dump_link_properties (const UCLinkProperties * prop)
 
   g_print ("\n\n"
 	   "	uid: %u\n"
+           "	treeview_path: %s\n"
 	   "	current_path: %s\n"
 	   "	link_type: %u\n"
+	   "	user_action: %s\n"
 	   "	link_value: %s\n"
 	   "	url: %s\n"
 	   "	normalized_url: %s\n"
@@ -640,6 +649,8 @@ uc_utils_debug_dump_link_properties (const UCLinkProperties * prop)
 	   "	is_parsable: %u\n"
 	   "	is_downloadable: %u\n"
 	   "	checked: %u\n"
+	   "	bookmark_folder_id: %i\n"
+	   "	bookmark_id: %i\n"
 	   "	to_delete: %u\n"
 	   "	metas: %u\n"
 	   "	emails: %u\n"
@@ -649,29 +660,36 @@ uc_utils_debug_dump_link_properties (const UCLinkProperties * prop)
 	   "	virii: %u\n"
 	   "	w3c_valid: %u\n",
 	   prop->uid,
-	   prop->current_path,
+	   (prop->treeview_path)?prop->treeview_path:"",
+	   (prop->current_path)?prop->current_path:"",
 	   prop->link_type,
-	   prop->link_value,
-	   prop->url,
-	   prop->normalized_url,
-	   prop->label,
-	   prop->protocol,
-	   prop->h_name,
-	   prop->port,
-	   prop-> path,
-	   prop-> args,
-	   prop-> domain,
-	   prop-> header_size,
-	   prop-> depth_level,
-	   prop-> is_parsable,
-	   prop-> is_downloadable,
-	   prop-> checked,
-	   prop-> to_delete,
-	   (prop-> metas != NULL),
-	   (prop-> emails != NULL),
-	   (prop-> childs != NULL),
-	   (prop-> similar_links_parents != NULL),
-	   (prop->bad_extensions != NULL), prop->virii, prop->w3c_valid);
+	   (prop->user_action)?prop->user_action:"",
+	   (prop->link_value)?prop->link_value:"",
+	   (prop->url)?prop->url:"",
+	   (prop->normalized_url)?prop->normalized_url:"",
+	   (prop->label)?prop->label:"",
+	   (prop->protocol)?prop->protocol:"",
+	   (prop->h_name)?prop->h_name:"",
+	   (prop->port)?prop->port:"",
+	   (prop->path)?prop-> path:"",
+	   (prop->args)?prop->args:"",
+	   (prop->domain)?prop->domain:"",
+	   prop->header_size,
+	   prop->depth_level,
+	   prop->is_parsable,
+	   prop->is_downloadable,
+	   prop->checked,
+           prop->bookmark_folder_id,
+           prop->bookmark_id,
+	   prop->to_delete,
+	   (prop->metas != NULL),
+	   (prop->emails != NULL),
+	   (prop->childs != NULL),
+	   (prop->similar_links_parents != NULL),
+	   (prop->bad_extensions != NULL),
+           prop->virii,
+           prop->w3c_valid
+        );
 }
 
 /**
@@ -918,6 +936,7 @@ uc_utils_mx_is_valid (const gchar * mx)
   return ret;
 }
 
+
 /**
  * uc_utils_get_ip:
  * @host: Host to work with.
@@ -933,15 +952,17 @@ uc_utils_get_ip (const gchar * host)
   struct hostent *serverHostEnt = NULL;
   gchar *buffer = NULL;
 
+
   if ((serverHostEnt = gethostbyname (host)) != NULL)
-    buffer = g_strdup (inet_ntoa
-		       (*((struct in_addr *) serverHostEnt->h_addr_list[0])));
-  else
-    buffer = (inet_addr (host) != -1) ? g_strdup (host) : g_strdup ("");
+    buffer = g_strdup (
+      inet_ntoa (*((struct in_addr *) serverHostEnt->h_addr_list[0])));
+  else if (inet_addr (host) != -1)
+    buffer = g_strdup (host);
 
   return buffer;
 }
 
+
 /**
  * uc_utils_string_format4display:
  * @label: Label to format.
@@ -1072,6 +1093,7 @@ uc_utils_replace (const gchar * str, const gchar * old, const gchar * new)
   return g_string_free (tmp, FALSE);
 }
 
+
 /**
  * uc_utils_replace1:
  * @string: String to work with.
@@ -1090,16 +1112,18 @@ uc_utils_replace1 (gchar * string, const gchar c1, const char c2)
 {
   gchar *p = string;
 
+
   do
-    {
-      if (*p == c1)
-	*p = c2;
-    }
+  {
+    if (*p == c1)
+      *p = c2;
+  }
   while (*p++);
 
   return string;
 }
 
+
 /**
  * uc_utils_replacelr:
  * @string: String to work with.
@@ -1140,6 +1164,7 @@ uc_utils_convert_uid2file (const guint32 uid)
 			  uc_project_get_cache_name (), uid);;
 }
 
+
 /**
  * uc_utils_get_gnome_browser_conf:
  * 
@@ -1154,18 +1179,16 @@ uc_utils_get_gnome_browser_conf (void)
   GConfClient *client = NULL;
   gchar *ret = NULL;
 
+
   client = gconf_client_get_default ();
-
-  ret =
-    gconf_client_get_string (client,
-			     "/desktop/gnome/url-handlers/http/command",
-			     NULL);
-
+  ret = gconf_client_get_string (
+          client, "/desktop/gnome/url-handlers/http/command", NULL);
   g_object_unref (client), client = NULL;
 
   return (ret == NULL) ? g_strdup ("mozilla") : ret;
 }
 
+
 /**
  * uc_utils_get_gnome_proxy_conf:
  * @host: A string to fill for the host.
@@ -1198,30 +1221,6 @@ uc_utils_get_gnome_proxy_conf (gchar ** host, guint * port)
   g_object_unref (client), client = NULL;
 }
 
-/**
- * uc_utils_disk_free_enough:
- * @requested_size: The size needed on the partition.
- * 
- * Check if there is enought space on the partition to write on it.
- * 
- * Returns: %TRUE if it exist enough space on the parition
- *          of the given path to write on it.
- */
-gboolean
-uc_utils_disk_free_enough (const guint32 requested_size)
-{
-  struct statfs sfs;
-  guint32 requested_blocks = 0;
-  guint32 secure_add = UC_SECURE_BYTES_ADDING;
-
-  statfs (uc_project_get_working_path (), &sfs);
-
-  secure_add /= sfs.f_bsize;
-  requested_blocks = ((requested_size / sfs.f_bsize) <= 0) ?
-    1 : requested_size / sfs.f_bsize;
-
-  return ((requested_blocks + secure_add) < sfs.f_bavail);
-}
 
 /**
  * uc_utils_clean_tag_link_value:
@@ -1250,6 +1249,7 @@ uc_utils_clean_tag_link_value (gchar * value)
   return g_string_free (buffer, FALSE);
 }
 
+
 /**
  * uc_utils_search_string_next:
  * @buf: A #gpointer to the source buffer.
@@ -1268,6 +1268,7 @@ uc_utils_search_string_next (gpointer buf, const gchar * str,
   gpointer sav = buf;
   gchar *buffer = (gchar *) buf;
 
+
   if (str == NULL || strlen (str) == 0 || buffer == NULL
       || strlen (buffer) < strlen (str))
     return (gpointer) buf;
@@ -1282,6 +1283,7 @@ uc_utils_search_string_next (gpointer buf, const gchar * str,
   return sav;
 }
 
+
 /**
  * uc_utils_memcasecmp:
  * @str1: First string to compare.
@@ -1299,6 +1301,7 @@ uc_utils_memcasecmp (const gchar * str1, const gchar * str2)
   guint32 len = 0;
   gboolean ret = FALSE;
 
+
   if (str1 == NULL || str2 == NULL)
     return FALSE;
 
@@ -1307,16 +1310,18 @@ uc_utils_memcasecmp (const gchar * str1, const gchar * str2)
   if (strlen (str1) < len)
     return FALSE;
 
-  if (!memcmp (str1, str2, len))
+  if (memcmp (str1, str2, len) == 0)
     return TRUE;
 
-  tmp = g_malloc0 (len + 1), memcpy (tmp, str1, len);
-  ret = (!g_ascii_strcasecmp (tmp, str2));
+  tmp = g_malloc0 (len + 1);
+  memcpy (tmp, str1, len);
+  ret = (g_ascii_strcasecmp (tmp, str2) == 0);
   g_free (tmp), tmp = NULL;
 
   return ret;
 }
 
+
 /**
  * uc_utils_mkdirs:
  * @path: Path to create.
@@ -1621,29 +1626,6 @@ uc_utils_strpbrk_or_eos (const gchar * str, const gchar * accept)
   return p;
 }
 
-/**
- * uc_utils_array_is_in:
- * @item: Item to search for.
- * @array: Vector to search in.
- * @size: Size of the vector.
- * 
- * Search for the first argument in the second argument vector.
- *
- * Returns: %TRUE if the first argument is in the second argument vector.
- */
-gboolean
-uc_utils_array_is_in (const gchar * item, gpointer array, const guint size)
-{
-  gchar **items = (gchar **) array;
-  guint i = 0;
-
-  for (i = 0; i < size; i++)
-    if (!strcmp (item, items[i]))
-      return TRUE;
-
-  return FALSE;
-}
-
 /**
  * uc_utils_get_server_from_header_field:
  * @field: A string from the "Server" HTTP header field.
@@ -1670,6 +1652,7 @@ uc_utils_get_server_from_header_field (gchar * field)
   return uc_utils_strdup_delim (b, e + 1);
 }
 
+
 /**
  * uc_utils_get_string_from_size:
  * @size: size to convert in string
@@ -1683,6 +1666,7 @@ uc_utils_get_string_from_size (const gsize size)
 {
   gchar *ret = NULL;
 
+
   if (size < 1024)
     ret = g_strdup_printf (_("%lu bytes"), (unsigned long) size);
   else if (size < (1024 * 1024))
@@ -1696,6 +1680,21 @@ uc_utils_get_string_from_size (const gsize size)
   return ret;
 }
 
+
+gboolean
+uc_utils_str_is_not_alphanum (const gchar *str)
+{
+  while (*str)
+  {
+    if (g_ascii_isalnum (*str) || g_ascii_isalpha (*str))
+      return FALSE;
+    ++str;
+  }
+
+  return TRUE;
+}
+
+
 /**
  * uc_utils_ftp_code_search:
  * @buffer: a buffer containing some FTP output stuff.
