@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2005 
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,7 @@
 
 #include "general.h"
 
+gboolean uc_utils_str_is_not_alphanum (const gchar *str);
 void uc_utils_clear_container (GtkContainer * container);
 void uc_utils_swap_file_proto_option (const gboolean begin);
 time_t uc_utils_http_atotm (const gchar * time_string);
@@ -63,7 +64,6 @@ gchar *uc_utils_replace (const gchar * str, const gchar * old,
 gchar *uc_utils_replace1 (gchar * string, const gchar c1, const char c2);
 gchar *uc_utils_replacelr (gchar * string, const gchar c);
 gchar *uc_utils_convert_uid2file (const guint32 uid);
-gboolean uc_utils_disk_free_enough (const guint32 requested_size);
 void uc_utils_get_gnome_proxy_conf (gchar ** host, guint * port);
 gchar *uc_utils_clean_tag_link_value (gchar * value);
 gpointer uc_utils_search_string_next (gpointer buf, const gchar * str,
@@ -75,8 +75,6 @@ void uc_utils_rmdirs (const gchar * path, const gboolean delete_all);
 guint32 uc_utils_vector_length (gpointer data);
 gchar *uc_utils_strpbrk_or_eos (const gchar * str, const gchar * accept);
 gchar *uc_utils_strdup_delim (const gchar * begin, const gchar * end);
-gboolean
-uc_utils_array_is_in (const gchar * item, gpointer array, const guint size);
 gboolean uc_utils_test_socket_open (const guint sock);
 gchar *uc_utils_get_gnome_browser_conf (void);
 
