@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2002-2005 
+ * Copyright (C) 2002-2010
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,6 +30,7 @@
 
 #include "web_site.h"
 
+
 static GList *uc_web_site_old_childs_list = NULL;
 
 static void uc_web_site_refresh_branch_real (GList * list);
@@ -40,6 +41,9 @@ static void uc_web_site_refresh_main_page (UCLinkProperties * prop);
 static void uc_web_site_refresh_apply_diff_main (GList * list, GList * sav,
 						 GList * main_list);
 static UCLinkProperties *uc_web_site_get_old_child (const gchar * url);
+static GList *uc_web_site_url_get_links (UCLinkProperties * url,
+                                         const guint depth);
+
 
 /*
  * get all the links of a page
@@ -57,78 +61,74 @@ uc_web_site_get_links_real (UCLinkProperties * prop,
   gchar *current_args = NULL;
   gboolean accept = FALSE;
 
-  (gboolean) uc_url_parse (prop->h_name, prop->path, prop->url, &current_host,
-			   &current_port, &current_path, &current_args);
+
+  uc_url_parse (prop->h_name, prop->path, prop->url, &current_host,
+                &current_port, &current_path, &current_args);
 
   if (prop->tags != NULL)
+  {
+    item = g_list_first (prop->tags);
+    while (UC_CHECK_PARSER_WHILE_CONDITION)
     {
       gchar *normalized_url = NULL;
+      UCHTMLTag *tag = (UCHTMLTag *) item->data;
+      UCLinkProperties *old_prop = NULL;
 
-      item = g_list_first (prop->tags);
-      while (UC_CHECK_PARSER_WHILE_CONDITION)
-	{
-	  UCHTMLTag *tag = (UCHTMLTag *) item->data;
-	  UCLinkProperties *old_prop = NULL;
 
-	  item = g_list_next (item);
+      item = g_list_next (item);
 
-	  /* META tag (already processed in the 
-	   * uc_check_link_get_properties () function ) */
-	  if (tag->type == LINK_TYPE_META || tag->type == LINK_TYPE_NONE)
-	    continue;
+      // META tag (already processed in the 
+      // uc_check_link_get_properties () function)
+      if (tag->type == LINK_TYPE_META || tag->type == LINK_TYPE_NONE)
+        continue;
 
-	  uc_report_set_alllinks (-1);
-	  uc_application_display_state_message (UC_CHECK_MESSAGE_LABEL_SECOND,
-						tag->value);
-	  UC_UPDATE_UI;
+      uc_report_set_alllinks (-1);
+      uc_application_display_state_message (UC_CHECK_MESSAGE_LABEL_SECOND,
+                                            tag->value);
+      UC_UPDATE_UI;
 
-	  normalized_url =
-	    uc_url_normalize (current_host, current_path, tag->value);
+      normalized_url = uc_url_normalize (current_host,
+                                         current_path, tag->value);
 
-	  uc_check_currentitem_init (prop,
-				     current_host, current_path,
-				     tag, normalized_url, tag->label, NULL);
+      uc_check_currentitem_init (prop, current_host, tag, normalized_url,
+                                 FALSE);
 
-	  if (uc_check_refresh_link_get_value ())
-	    old_prop = uc_web_site_get_old_child (normalized_url);
+      if (uc_check_refresh_link_get_value ())
+        old_prop = uc_web_site_get_old_child (normalized_url);
 
-	  /* retrieve properties of the link and check if its
-	   * ok for register */
-	  lp = uc_check_link_get_properties (depth, current_host,
-					     current_path,
-					     (UCHTMLTag *) tag,
-					     old_prop, &accept, 0);
+      // Retrieve properties of the link and check if its ok for register
+      lp = uc_check_link_get_properties (depth, current_host,
+                                         current_path, (UCHTMLTag *) tag,
+                                         old_prop, &accept, 0);
 
-	  if (lp != NULL && accept)
-	    {
-	      list = g_list_append (list,
-				    uc_check_register_link
-				    (normalized_url, lp));
-	      lp->normalized_url = normalized_url;
+      if (lp != NULL && accept)
+      {
+        lp->normalized_url = normalized_url;
+        list = g_list_append (list,
+                               uc_check_register_link (normalized_url, lp));
 
-	      /* Run security tests if requested */
-	      if (uc_project_get_security_checks ("any"))
-		uc_check_run_security_checks (lp);
+        // Run security tests if requested */
+        if (uc_project_get_security_checks ("any"))
+          uc_check_run_security_checks (lp);
 
-	      /* Run w3c tests if requested */
-	      if (uc_project_get_w3c_checks ("any"))
-		uc_check_run_w3c_checks (lp);
+        // Run w3c tests if requested */
+        if (uc_project_get_w3c_checks ("any"))
+          uc_check_run_w3c_checks (lp);
 
-	      uc_check_wait ();
-	    }
-	  /* link rejected */
-	  else
-	    {
-	      if (lp != NULL)
-		(GList *) uc_lists_checked_links_node_free (NULL,
-							    (gpointer) lp);
+        uc_check_wait ();
+      }
+      // Rejected link
+      else
+      {
+        if (lp != NULL)
+          uc_lists_checked_links_node_free (NULL, &lp);
 
-	      g_free (normalized_url), normalized_url = NULL;
-	    }
+        g_free (normalized_url), normalized_url = NULL;
+      }
 
-	  uc_report_display_update ();
-	}
+       uc_report_display_update ();
     }
+  }
 
   if (current_host)
     g_free (current_host), current_host = NULL;
@@ -142,11 +142,12 @@ uc_web_site_get_links_real (UCLinkProperties * prop,
   return list;
 }
 
+
 /*
  * put in a list all the urls of
  * a given url
  */
-GList *
+static GList *
 uc_web_site_url_get_links (UCLinkProperties * prop, const guint depth)
 {
   gchar *host = NULL;
@@ -154,6 +155,7 @@ uc_web_site_url_get_links (UCLinkProperties * prop, const guint depth)
   GList *item = NULL;
   GList *tmp_list = NULL;
 
+
   if (prop == NULL)
     return NULL;
 
@@ -194,7 +196,7 @@ uc_web_site_url_get_links (UCLinkProperties * prop, const guint depth)
 	  /* Mark this link as already checked */
 	  prop->checked = TRUE;
 
-	  uc_utils_debug ("Checking %s...\n", lp->url);
+	  uc_utils_debug ("Checking %s...\n", (lp->url)?lp->url:"");
 	  lp->childs = uc_web_site_url_get_links (lp, depth + 1);
 	}
 
@@ -212,17 +214,19 @@ uc_web_site_refresh_branch_real (GList * list)
 {
   GList *item = NULL;
 
+
   item = g_list_first (list);
   while (UC_CHECK_PARSER_WHILE_CONDITION)
     {
       UCLinkProperties *prop = (UCLinkProperties *) item->data;
 
+
+      item = g_list_next (item);
+
       uc_web_site_refresh_link_real (prop);
 
       if (prop->childs != NULL && !uc_check_is_main_page (prop))
 	uc_web_site_refresh_branch_real (prop->childs);
-
-      item = g_list_next (item);
     }
 }
 
@@ -262,6 +266,8 @@ uc_web_site_refresh_link (const gint32 id)
 
   uc_application_set_status_bar (0, _("Updating link..."));
   uc_application_progress_dialog_show ();
+  uc_application_display_state_message (UC_CHECK_MESSAGE_LABEL_FIRST,
+                                        _("Check in progress..."));
   WSENS ("bt_ignore_progress_dialog", FALSE);
   WSENS ("bt_suspend_progress_dialog", FALSE);
   UC_UPDATE_UI;
@@ -287,7 +293,8 @@ uc_web_site_refresh_link (const gint32 id)
   uc_check_cancel_set_value (FALSE);
   uc_project_set_check_is_current (FALSE);
 
-  uc_project_set_save (TRUE);
+  if (!uc_project_get_check_is_bookmarks ())
+    uc_project_set_save (TRUE);
 
   uc_application_set_status_bar (0, "");
 
@@ -306,6 +313,7 @@ uc_web_site_refresh_main_page (UCLinkProperties * prop)
   GtkTreePath *treepath = NULL;
   GList *main_list = NULL;
 
+
   uc_check_refresh_link_set_value (TRUE);
 
   /* get main page links and set it temporarly as childs */
@@ -327,23 +335,20 @@ uc_web_site_refresh_main_page (UCLinkProperties * prop)
 
   uc_lists_already_checked_links_remove_items (prop);
 
-  uc_check_currentitem_init (NULL, prop->h_name, "",
-			     prop->tag, prop->normalized_url,
-			     prop->label, NULL);
+  uc_check_currentitem_init (NULL, prop->h_name, prop->tag,
+                             prop->normalized_url, FALSE);
 
   uc_lists_refresh_preserved_links_reset ();
 
-  new_prop = uc_check_link_get_properties (0,
-					   prop->h_name,
-					   prop->current_path,
-					   (UCHTMLTag *) prop->tag,
-					   (prop->childs !=
-					    NULL) ? NULL : prop, &accept, 0);
+  new_prop = uc_check_link_get_properties (
+    0, prop->h_name, prop->current_path, (UCHTMLTag *) prop->tag,
+    (prop->childs != NULL) ? NULL : prop, &accept, 0);
 
   if (new_prop != NULL && accept)
     {
       new_prop->normalized_url = g_strdup (prop->url);
-      (gpointer) uc_check_register_link (uc_project_get_url (), prop);
+// FIXME
+      uc_check_register_link (uc_project_get_url (), prop);
 
       list = uc_web_site_get_links_real (new_prop, new_prop->h_name, 0);
       main_list = uc_lists_checked_links_get ();
@@ -358,7 +363,7 @@ uc_web_site_refresh_main_page (UCLinkProperties * prop)
       uc_check_set_depth (uc_lists_checked_links_get (), 0);
     }
   else if (new_prop != NULL)
-    (GList *) uc_lists_checked_links_node_free (NULL, new_prop);
+    uc_lists_checked_links_node_free (NULL, &new_prop);
 
   treepath = gtk_tree_path_new_from_string (prop->treeview_path);
   uc_application_main_tree_display_all ();
@@ -407,7 +412,7 @@ uc_web_site_refresh_apply_diff_main (GList * list, GList * sav,
 	      if (!found)
 		{
 		  uc_lists_already_checked_links_remove_branch_items (lp1);
-		  main_list = g_list_remove (main_list, lp1);
+		  main_list = g_list_remove (main_list, (gpointer) lp1);
 		  lp1 = NULL;
 		}
 	    }
@@ -427,6 +432,7 @@ uc_web_site_refresh_apply_diff_main (GList * list, GList * sav,
 	      GList *item2 = NULL;
 	      g_list_free (lp->childs), lp->childs = NULL;
 	      lp->childs = lp1->childs;
+              // FIXME
 	      lp->depth_level = 0;
 
 	      /* on parcours les anciens enfant et on leur donne le
@@ -436,6 +442,7 @@ uc_web_site_refresh_apply_diff_main (GList * list, GList * sav,
 		{
 		  UCLinkProperties *lp2 = (UCLinkProperties *) item2->data;
 		  lp2->parent = lp;
+                  // FIXME
 		  lp2->depth_level = 1;
 		  item2 = g_list_next (item2);
 		}
@@ -493,7 +500,7 @@ uc_web_site_refresh_apply_diff (GList * list, GList * sav,
 	      if (!found)
 		{
 		  uc_lists_already_checked_links_remove_branch_items (lp1);
-		  prop->childs = g_list_remove (prop->childs, lp1);
+		  prop->childs = g_list_remove (prop->childs, (gpointer) lp1);
 		  lp1 = NULL;
 		}
 	    }
@@ -533,25 +540,29 @@ uc_web_site_refresh_apply_diff (GList * list, GList * sav,
     }
 }
 
+
 static UCLinkProperties *
 uc_web_site_get_old_child (const gchar * url)
 {
   GList *item = NULL;
 
+
   item = g_list_first (uc_web_site_old_childs_list);
   while (item != NULL)
-    {
-      UCLinkProperties *prop = (UCLinkProperties *) item->data;
+  {
+    UCLinkProperties *prop = (UCLinkProperties *) item->data;
 
-      if (!g_ascii_strcasecmp (url, prop->normalized_url))
-	return prop;
 
-      item = g_list_next (item);
-    }
+    if (!g_ascii_strcasecmp (url, prop->normalized_url))
+      return prop;
+
+    item = g_list_next (item);
+  }
 
   return NULL;
 }
 
+
 static void
 uc_web_site_refresh_link_real (UCLinkProperties * prop)
 {
@@ -592,12 +603,8 @@ uc_web_site_refresh_link_real (UCLinkProperties * prop)
     uc_url_normalize (uc_project_get_current_host (),
 		      parent->path, ((UCHTMLTag *) prop->tag)->value);
 
-  uc_check_currentitem_init (prop,
-			     uc_project_get_current_host (),
-			     parent->current_path,
-			     prop->tag,
-			     normalized_url,
-			     ((UCHTMLTag *) prop->tag)->label, NULL);
+  uc_check_currentitem_init (prop, uc_project_get_current_host (), prop->tag,
+                             normalized_url, FALSE);
 
   /* remove links in already checked list to check them
    * again */
@@ -618,7 +625,8 @@ uc_web_site_refresh_link_real (UCLinkProperties * prop)
       new_status = g_hash_table_lookup (new_prop->header, UC_HEADER_STATUS);
 
       new_prop->normalized_url = normalized_url;
-      (gpointer) uc_check_register_link (normalized_url, prop);
+// FIXME
+      uc_check_register_link (normalized_url, prop);
 
       /* we do not check other site that the main site */
       if (!g_ascii_strcasecmp (uc_project_get_current_host (), prop->h_name))
@@ -651,7 +659,7 @@ uc_web_site_refresh_link_real (UCLinkProperties * prop)
   else
     {
       if (new_prop != NULL)
-	(GList *) uc_lists_checked_links_node_free (NULL, new_prop);
+        uc_lists_checked_links_node_free (NULL, &new_prop);
 
       g_free (normalized_url), normalized_url = NULL;
     }
@@ -701,7 +709,8 @@ uc_web_site_refresh_branch (const gint32 id)
   uc_project_set_check_is_current (FALSE);
   uc_check_cancel_set_value (FALSE);
 
-  uc_project_set_save (TRUE);
+  if (!uc_project_get_check_is_bookmarks ())
+    uc_project_set_save (TRUE);
 
   uc_application_set_status_bar (0, "");
 
@@ -746,7 +755,8 @@ uc_web_site_refresh_all (void)
   uc_project_set_check_is_current (FALSE);
   uc_check_cancel_set_value (FALSE);
 
-  uc_project_set_save (TRUE);
+  if (!uc_project_get_check_is_bookmarks ())
+    uc_project_set_save (TRUE);
 
   uc_application_set_status_bar (0, "");
 
@@ -771,6 +781,7 @@ uc_web_site_begin_check (void)
   gboolean have_redir = FALSE;
   UCHTMLTag *tag = NULL;
   gchar *error_msg = NULL;
+  GtkTreeIter iter;
 
   uc_application_draw_main_frames ();
   uc_application_progress_dialog_show ();
@@ -823,10 +834,11 @@ uc_web_site_begin_check (void)
   UC_UPDATE_UI;
 
   /* get properties for the main page */
-  uc_check_currentitem_init (NULL, uc_project_get_current_host (), "",
-			     tag, uc_project_get_url (), tag->label, NULL);
+  uc_check_currentitem_init (NULL, uc_project_get_current_host (), tag,
+                             uc_project_get_url (), TRUE);
   prop = uc_check_link_get_properties (0, uc_project_get_current_host (), "",
 				       (UCHTMLTag *) tag, NULL, &accept, 0);
+
   if (prop != NULL)
     {
       /* authentication needed but user did not provided login/password */
@@ -846,7 +858,7 @@ uc_web_site_begin_check (void)
       if (have_redir)
 	uc_project_set_current_host (prop->h_name);
 
-      uc_utils_debug ("Checking %s...\n", prop->url);
+      uc_utils_debug ("Checking %s...\n", (prop->url)?prop->url:"");
 
       /* retreive project's pages */
       uc_project_set_check_is_current (TRUE);
@@ -869,16 +881,24 @@ uc_web_site_begin_check (void)
 
 	/* display main tree view */
 	gtk_tree_store_clear (treestore);
-	uc_check_display_list (uc_lists_checked_links_get (), NULL);
+
+        UC_DISPLAY_SET_ALL;
+	uc_check_display_list (uc_lists_checked_links_get (), NULL, iter);
 
 	/* update application menu */
+        WSENS ("mwm_delete_all_bad_links", FALSE);
 	WSENS ("mwm_display", TRUE);
 	WSENS ("mwm_refresh_all", TRUE);
 	WSENS ("mwm_refresh_main_page", TRUE);
 	WSENS ("mwm_find", !uc_project_get_speed_check ());
 	WSENS ("mwm_project_properties", TRUE);
-	WSENS ("mwm_display_security_alerts",
-	       uc_project_get_type () == UC_PROJECT_TYPE_WEB_SITE);
+#ifndef ENABLE_GNUTLS
+        if (strcmp (prop->protocol, UC_PROTOCOL_HTTPS) == 0)
+          WSENS ("mwm_refresh_main_page", FALSE);
+#endif
+#ifdef ENABLE_CLAMAV
+        WSENS ("mwm_display_security_alerts", !uc_project_get_speed_check ());
+#endif
 
 	uc_project_set_save (TRUE);
       }
